%define anolis_release 1
 
Name:           bash
Version:        5.2.15
Release:        %{anolis_release}%{?dist}
Summary:        The GNU Bourne Again shell

License:        GPLv3+
URL:            https://www.gnu.org/software/bash
Source0:	https://ftp.gnu.org/gnu/bash/%{name}-%{version}.tar.gz
Source1:        dot-bashrc
Source2:        dot-bash_profile
Source3:        dot-bash_logout

BuildRequires:	gcc
BuildRequires:	texinfo
BuildRequires:	bison
BuildRequires:	ncurses-devel
BuildRequires:	readline-devel >= 8.2
BuildRequires:	autoconf
BuildRequires:	gettext-devel
BuildRequires:	make
# Required for bash tests
BuildRequires:	glibc-all-langpacks
Requires:       filesystem
# Per requested by upstream
# https://lists.gnu.org/archive/html/bug-bash/2022-10/msg00105.html
Requires:	readline >= 8.2
Requires(post):	lua
Requires(postun): lua
Provides:       /bin/sh /bin/bash

%description
The GNU Bourne Again shell (Bash) is a shell or command language
interpreter that is compatible with the Bourne shell (sh). Bash
incorporates useful features from the Korn shell (ksh) and the C shell
(csh). Most sh scripts can be run by bash without modification.

%package devel
Summary: Development headers for %{name}
Requires: %{name} = %{version}-%{release}

%description devel
This package contains development headers for %{name}.

%package doc
Summary: Documentation files for %{name}
Buildarch: noarch
Requires: %{name} = %{version}-%{release}

%description doc
This package contains documentation files for %{name}.

%prep
%autosetup -p1 -n bash-%{version}

%build
autoconf
%configure --with-bash-malloc=no --with-afs \
	--without-included-gettext \
	--enable-readline --with-installed-readline
make version.h
%make_build -C builtins
%make_build

%install
%make_install install-headers

ln -sf bash %{buildroot}%{_bindir}/sh

for ea in alias bg cd command fc fg getopts hash jobs read type ulimit umask unalias wait
do
  cat <<EOF > "%{buildroot}"/%{_bindir}/"$ea"
#!/bin/sh
builtin $ea "\$@"
EOF
chmod +x "%{buildroot}"/%{_bindir}/"$ea"
done

mkdir -p %{buildroot}/etc/skel/
install -p -m644 %SOURCE1 %SOURCE2 %SOURCE3 %{buildroot}/etc/skel/
rename dot- . %{buildroot}/etc/skel/dot-*

%find_lang %{name}

install -d %{buildroot}/%{_pkgdocdir}/doc
install -p CHANGES COMPAT NEWS NOTES POSIX RBASH README %{buildroot}%{_pkgdocdir}/

rm -rf examples/loadables
cp -rp examples %{buildroot}/%{_pkgdocdir}/doc/

ls %{buildroot}/%{_pkgdocdir}/ | xargs -i echo "%%doc %{_pkgdocdir}/{}" >> %{name}-doc.files

rm -rf %{buildroot}%{_libdir}/%{name} %{buildroot}/usr/lib/debug %{buildroot}%{_bindir}/bashbug %{buildroot}/usr/share/info/dir 

%check
make check

%post -p <lua>
nl        = '\n'
sh        = '/bin/sh'..nl
bash      = '/bin/bash'..nl
f = io.open('/etc/shells', 'a+')
if f then
  local shells = nl..f:read('*all')..nl
  if not shells:find(nl..sh) then f:write(sh) end
  if not shells:find(nl..bash) then f:write(bash) end
  f:close()
end

%postun -p <lua>
-- Run it only if we are uninstalling
if arg[2] == 0
then
  t={}
  for line in io.lines("/etc/shells")
  do
    if line ~= "/bin/bash" and line ~= "/bin/sh"
    then
      table.insert(t,line)
    end
  end

  f = io.open("/etc/shells", "w+")
  for n,line in pairs(t)
  do
    f:write(line.."\n")
  end
  f:close()
end

%files -f %{name}.lang
%config(noreplace) /etc/skel/.b*
%{_bindir}/sh
%{_bindir}/bash
%{_bindir}/alias
%{_bindir}/bg
%{_bindir}/cd
%{_bindir}/command
%{_bindir}/fc
%{_bindir}/fg
%{_bindir}/hash
%{_bindir}/getopts
%{_bindir}/jobs
%{_bindir}/read
%{_bindir}/type
%{_bindir}/ulimit
%{_bindir}/umask
%{_bindir}/unalias
%{_bindir}/wait
%license COPYING
%{_infodir}/bash.info*
%{_mandir}/*/*
%doc RBASH README
%doc doc/{FAQ,INTRO,bash{,ref}.html}

%files doc -f %{name}-doc.files
%doc doc/*.ps doc/*.0 doc/*.html doc/article.txt

%files devel
%{_includedir}/%{name}
%{_libdir}/pkgconfig/%{name}.pc

%changelog
* Thu Dec 15 2022 Funda Wang <fundawang@yeah.net> - 5.2.15-1
- New version 5.2.15

* Fri Dec 2 2022 Funda Wang <fundawang@yeah.net> - 5.2.9-1
- New version 5.2.9

* Mon Mar  21 2022 forrest_ly <flin@linux.alibaba.com> - 5.2~alpha-2
- Fix some bugs from upstream 

* Tue Mar  1 2022 forrest_ly <flin@linux.alibaba.com> - 5.2~alpha-1
- Init for Anolis OS 23 
